@@ -27,13 +27,12 @@
 //
 //*************************************************************************//
 
+void setendless2(int e);
+void setlength2(int32_t stop, int32_t fade);
 
-void SetupTimer(void);
-void RemoveTimer(void);
-EXPORT_GCC void CALLBACK SPU2playADPCMchannel(xa_decode_t *xap);
+long SPU2init(void);
+long SPU2open(void *pDsp);
+void SPU2async(void (*update)(const void *, int));
+void SPU2close(void);
 
-EXPORT_GCC long CALLBACK SPU2init(void);
-EXPORT_GCC long CALLBACK SPU2open(void *pDsp);
-EXPORT_GCC void CALLBACK SPU2async(void (*update)(const void *, int));
-EXPORT_GCC void CALLBACK SPU2close(void);
-EXPORT_GCC int  CALLBACK psf2_seek(u32 t);
+int psf2_seek(uint32_t t);
