@@ -38,6 +38,8 @@ PlaylistWidget::PlaylistWidget(QWidget * parent, Playlist playlist)
       model(new PlaylistModel(this, playlist)),
       proxyModel(new PlaylistProxyModel(this, playlist))
 {
+    model->setFont(font());
+
     /* setting up filtering model */
     proxyModel->setSourceModel(model);
 
@@ -59,8 +61,6 @@ PlaylistWidget::PlaylistWidget(QWidget * parent, Playlist playlist)
     setDragDropMode(DragDrop);
     setMouseTracking(true);
 
-    connect(this, &QTreeView::activated, this, &PlaylistWidget::activate);
-
     updateSettings();
     header->updateColumns();
 
@@ -68,6 +68,14 @@ PlaylistWidget::PlaylistWidget(QWidget * parent, Playlist playlist)
     inUpdate = true;
     updateSelection(0, 0);
     inUpdate = false;
+
+    connect(this, &QTreeView::activated, [this](const QModelIndex & index) {
+        if (index.isValid())
+        {
+            m_playlist.set_position(indexToRow(index));
+            m_playlist.start_playback();
+        }
+    });
 }
 
 PlaylistWidget::~PlaylistWidget()
@@ -117,13 +125,12 @@ QModelIndex PlaylistWidget::visibleIndexNear(int row)
     return index;
 }
 
-void PlaylistWidget::activate(const QModelIndex & index)
+void PlaylistWidget::changeEvent(QEvent * event)
 {
-    if (index.isValid())
-    {
-        m_playlist.set_position(indexToRow(index));
-        m_playlist.start_playback();
-    }
+    if (event->type() == QEvent::FontChange)
+        model->setFont(font());
+
+    audqt::TreeView::changeEvent(event);
 }
 
 void PlaylistWidget::contextMenuEvent(QContextMenuEvent * event)
@@ -519,9 +526,8 @@ void PlaylistWidget::triggerPopup(int pos)
     audqt::infopopup_hide();
 
     m_popup_pos = pos;
-    m_popup_timer.queue(
-        aud_get_int("filepopup_delay") * 100,
-        aud::obj_member<PlaylistWidget, &PlaylistWidget::showPopup>, this);
+    m_popup_timer.queue(aud_get_int("filepopup_delay") * 100,
+                        [this]() { showPopup(); });
 }
 
 void PlaylistWidget::hidePopup()
