@@ -190,7 +190,7 @@ static void mainwin_lock_info_text (const char * text)
     locked_textbox->set_text (text);
 }
 
-static void mainwin_release_info_text (void * = nullptr)
+static void mainwin_release_info_text ()
 {
     if (locked_textbox)
     {
@@ -214,7 +214,7 @@ static void set_info_text (TextBox * textbox, const char * text)
 void mainwin_show_status_message (const char * message)
 {
     mainwin_lock_info_text (message);
-    status_message_timeout.queue (1000, mainwin_release_info_text, nullptr);
+    status_message_timeout.queue (1000, mainwin_release_info_text);
 }
 
 static void mainwin_set_song_title (const char * title)
@@ -329,7 +329,7 @@ static void mainwin_set_song_info (int bitrate, int samplerate, int channels)
     mainwin_monostereo->set_num_channels (channels);
 
     if (bitrate > 0)
-        snprintf (scratch, sizeof scratch, "%d kbps", bitrate / 1000);
+        snprintf (scratch, sizeof scratch, "%d kbit/s", bitrate / 1000);
     else
         scratch[0] = 0;
 
@@ -483,7 +483,7 @@ bool MainWindow::scroll (QWheelEvent * event)
     {
         m_scroll_delta_y -= 120 * steps_y;
         int volume_delta = aud_get_int ("volume_delta");
-        aud_drct_set_volume_main (aud_drct_get_volume_main () + steps_y * volume_delta);
+        mainwin_set_volume_diff (steps_y * volume_delta);
     }
 
     return true;
@@ -805,8 +805,7 @@ void mainwin_set_volume_diff (int diff)
     mainwin_set_volume_slider (vol);
     equalizerwin_set_volume_slider (vol);
 
-    mainwin_volume_release_timeout.queue (700,
-     [] (void *) { mainwin_volume_release_cb (); }, nullptr);
+    mainwin_volume_release_timeout.queue (700, mainwin_volume_release_cb);
 }
 
 void mainwin_mr_change (MenuRowItem i)
@@ -1097,7 +1096,7 @@ void MainWindow::draw (QPainter & cr)
     int height = is_shaded () ? MAINWIN_SHADED_HEIGHT : skin.hints.mainwin_height;
 
     skin_draw_pixbuf (cr, SKIN_MAIN, 0, 0, 0, 0, width, height);
-    skin_draw_mainwin_titlebar (cr, is_shaded (), true);
+    skin_draw_mainwin_titlebar (cr, is_shaded (), is_focused ());
 }
 
 static void mainwin_create_window ()
