@@ -94,7 +94,6 @@ static Button * button_add, * button_sub, * button_sel, * button_misc, * button_
 
 static int resize_base_width, resize_base_height;
 static int drop_position;
-static bool song_changed;
 
 static void update_info ()
 {
@@ -505,12 +504,6 @@ static void update_cb (void *, void *)
 {
     playlistwin_list->refresh ();
 
-    if (song_changed)
-    {
-        playlistwin_list->set_focused (Playlist::active_playlist ().get_position ());
-        song_changed = false;
-    }
-
     update_info ();
     update_rollup_text ();
 }
@@ -522,10 +515,11 @@ static void follow_cb (void * data, void *)
 
     int row = list.get_position ();
     if (row >= 0)
+    {
         list.select_entry (row, true);
-
-    if (list == Playlist::active_playlist ())
-        song_changed = true;
+        if (list == Playlist::active_playlist ())
+            playlistwin_list->set_focused (row);
+    }
 }
 
 void playlistwin_create ()
@@ -536,8 +530,6 @@ void playlistwin_create ()
     update_info ();
     update_rollup_text ();
 
-    song_changed = false;
-
     hook_associate ("playlist position", follow_cb, nullptr);
     hook_associate ("playlist activate", update_cb, nullptr);
     hook_associate ("playlist update", update_cb, nullptr);
